@@ -2,7 +2,7 @@
    standard output.  Read and ignore any data sent to terminal.  This
    is so we can run tests interactively without messing up the screen.
 
-   Copyright 2014, 2015, 2016 Free Software Foundation, Inc.
+   Copyright 2014-2019 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if HAVE_STROPTS_H
+#if defined __sun || defined __hpux /* Solaris, HP-UX */
 #include <stropts.h>
 #endif
 
@@ -64,27 +64,23 @@ main (int argc, char *argv[])
     exit (1);
   error (0, 0, "%s", name);
 
-#ifdef HAVE_STROPTS_H
   error (0, 0, "opening slave device");
   slave = open (name, O_RDWR);
   if (slave == -1)
     exit (1);
-  if (!isatty (slave))
+
+#if defined __sun || defined __hpux /* Solaris, HP-UX */
+  if (isastream (slave))
     {
       error (0, 0, "performing STREAMS ioctl's on slave");
-      if (isastream (slave))
-        {
-          if (ioctl (slave, I_PUSH, "ptem") < 0
-              || ioctl (slave, I_PUSH, "ldterm") < 0)
-            error (1, 0, "STREAMS ioctl's failed");
-        }
+      if (ioctl (slave, I_PUSH, "ptem") < 0
+          || ioctl (slave, I_PUSH, "ldterm") < 0
+#  if defined __sun
+          || ioctl (slave, I_PUSH, "ttcompat") < 0
+#  endif
+         )
+        error (1, 0, "STREAMS ioctl's failed");
     }
-  /* Don't close it because it just leads to an EOF read at the master end. */
-  /*
-  error (0, 0, "closing slave device");
-  close (slave);
-  error (0, 0, "...closed");
-  */
 #endif
 
 #if defined (HAVE_TERMIOS_H)
@@ -100,6 +96,9 @@ main (int argc, char *argv[])
       t.c_cc[VSTOP] = disable;  /* C-s */
       t.c_cc[VKILL] = disable;  /* C-u */
       t.c_cc[VINTR] = disable;  /* C-c */
+      t.c_lflag &= (~ICANON & ~ECHO);
+      t.c_cc[VMIN] = 1;
+      t.c_cc[VTIME] = 0;
       if (tcsetattr (slave, TCSANOW, &t) == -1)
         error (0, 0, "error calling tcsetattr");
     }
