@@ -1,7 +1,6 @@
 /* tag.c -- Functions to handle Info tags.
-   $Id: tag.h 5823 2014-09-12 17:22:40Z gavin $
 
-   Copyright 2012, 2013, 2014 Free Software Foundation, Inc.
+   Copyright 2012-2019 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,6 +20,7 @@
 
 #include "info-utils.h"
 
-int tag_expand (char **input, struct text_buffer *outbuf, int *is_index);
+int tag_expand (char **input, char *input_end,
+                struct text_buffer *outbuf, int *is_index);
 
 #endif
