@@ -129,7 +129,9 @@ $result_trees{'simplest_test_date_in_header'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -176,7 +178,7 @@ $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'contents'}[1]{'con
 $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'simplest_test_date_in_header'}{'contents'}[1];
 $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'simplest_test_date_in_header'}{'contents'}[1];
 $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'simplest_test_date_in_header'}{'contents'}[1]{'parent'} = $result_trees{'simplest_test_date_in_header'};
 $result_trees{'simplest_test_date_in_header'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'simplest_test_date_in_header'}{'contents'}[2];
 $result_trees{'simplest_test_date_in_header'}{'contents'}[2]{'parent'} = $result_trees{'simplest_test_date_in_header'};
@@ -220,6 +222,9 @@ $result_menus{'simplest_test_date_in_header'} = {
 $result_errors{'simplest_test_date_in_header'} = [];
 
 
+$result_floats{'simplest_test_date_in_header'} = {};
+
+
 $result_converted_errors{'file_html'}->{'simplest_test_date_in_header'} = [
   {
     'error_line' => 'simplest.texi: warning: must specify a title with a title command or @top
