@@ -26,7 +26,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 1,
@@ -47,7 +49,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 1,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -79,7 +85,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 3,
@@ -100,7 +108,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 3,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -132,7 +144,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 5,
@@ -153,7 +167,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 5,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -185,7 +203,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 7,
@@ -210,7 +230,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 7,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -253,7 +277,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 11,
@@ -297,7 +323,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 13,
@@ -324,8 +352,14 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 13,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -365,7 +399,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 16,
@@ -482,7 +518,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 19,
@@ -503,7 +541,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 19,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -569,7 +611,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 21,
@@ -590,7 +634,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 21,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -656,7 +704,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 23,
@@ -677,7 +727,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 23,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -743,7 +797,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 25,
@@ -768,7 +824,11 @@ $result_trees{'multiline_image_and_align'} = {
       'extra' => {
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => '',
+        'line_nr' => 25,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -845,7 +905,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 29,
@@ -923,7 +985,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 31,
@@ -984,8 +1048,14 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
-              'line_nr' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
+              'line_nr' => {
+                'file_name' => '',
+                'line_nr' => 31,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -1059,7 +1129,9 @@ $result_trees{'multiline_image_and_align'} = {
               ],
               'cmdname' => 'image',
               'contents' => [],
-              'extra' => {},
+              'extra' => {
+                'input_perl_encoding' => 'utf-8'
+              },
               'line_nr' => {
                 'file_name' => '',
                 'line_nr' => 34,
@@ -1124,7 +1196,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[0]{'args'}[0]{'contents'}
 $result_trees{'multiline_image_and_align'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[0]{'args'}[0]{'contents'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[0]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[0];
-$result_trees{'multiline_image_and_align'}{'contents'}[0]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[0]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[1]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0];
@@ -1132,7 +1203,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0]{'contents'}
 $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0]{'contents'}[1];
 $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[2];
-$result_trees{'multiline_image_and_align'}{'contents'}[2]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[2]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[2]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[3]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0];
@@ -1140,7 +1210,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0]{'contents'}
 $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0]{'contents'}[1];
 $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[4];
-$result_trees{'multiline_image_and_align'}{'contents'}[4]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[4]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[4]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[5]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0];
@@ -1149,7 +1218,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0]{'contents'}
 $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[6];
-$result_trees{'multiline_image_and_align'}{'contents'}[6]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[6]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[6]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[7]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[0]{'extra'}{'command'} = $result_trees{'multiline_image_and_align'}{'contents'}[8];
@@ -1168,7 +1236,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'conten
 $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3];
 $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[3]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[3]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[3];
-$result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[3]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[3]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3];
 $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'contents'}[4]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3];
 $result_trees{'multiline_image_and_align'}{'contents'}[8]{'contents'}[3]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[8];
@@ -1194,7 +1261,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[10]{'args'}[0]{'contents'
 $result_trees{'multiline_image_and_align'}{'contents'}[10]{'args'}[0]{'contents'}[0]{'args'}[4]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[10]{'args'}[0]{'contents'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[10]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[10]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[10];
-$result_trees{'multiline_image_and_align'}{'contents'}[10]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[10]{'args'}[0]{'contents'}[0]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[10]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[11]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0];
@@ -1207,7 +1273,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0]{'contents'
 $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0]{'contents'}[1]{'args'}[4]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0]{'contents'}[1];
 $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[12];
-$result_trees{'multiline_image_and_align'}{'contents'}[12]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[12]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[12]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[13]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0];
@@ -1220,7 +1285,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0]{'contents'
 $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0]{'contents'}[1]{'args'}[4]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0]{'contents'}[1];
 $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[14];
-$result_trees{'multiline_image_and_align'}{'contents'}[14]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[14]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[14]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[15]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0];
@@ -1234,7 +1298,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0]{'contents'
 $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0];
 $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[16];
-$result_trees{'multiline_image_and_align'}{'contents'}[16]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[16]{'args'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[16]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[17]{'parent'} = $result_trees{'multiline_image_and_align'};
 $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[0]{'extra'}{'command'} = $result_trees{'multiline_image_and_align'}{'contents'}[18];
@@ -1268,7 +1331,6 @@ $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'conte
 $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3]{'args'}[3]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3];
 $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3]{'args'}[4]{'contents'}[0]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3]{'args'}[4];
 $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3]{'args'}[4]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3];
-$result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3]{'line_nr'} = $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[1]{'line_nr'};
 $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[3]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3];
 $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'contents'}[4]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3];
 $result_trees{'multiline_image_and_align'}{'contents'}[18]{'contents'}[3]{'parent'} = $result_trees{'multiline_image_and_align'}{'contents'}[18];
@@ -1364,6 +1426,9 @@ figure JJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJ
 $result_errors{'multiline_image_and_align'} = [];
 
 
+$result_floats{'multiline_image_and_align'} = {};
+
+
 
 $result_converted{'info'}->{'multiline_image_and_align'} = 'This is , produced from .
 
@@ -1435,6 +1500,11 @@ BBB  [image src="figure.txt" text="  1  A  B
 Tag Table:
 
 End Tag Table
+
+
+Local Variables:
+coding: utf-8
+End:
 ';
 
 $result_converted_errors{'info'}->{'multiline_image_and_align'} = [
