@@ -176,7 +176,11 @@ $result_trees{'node_footnote_separated'} = {
                   'normalized' => '_00e1'
                 }
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => 'node_footnote.texi',
+                'line_nr' => 8,
+                'macro' => ''
+              },
               'parent' => {},
               'type' => 'menu_entry'
             },
@@ -247,7 +251,11 @@ $result_trees{'node_footnote_separated'} = {
                   'normalized' => '_00e2'
                 }
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => 'node_footnote.texi',
+                'line_nr' => 9,
+                'macro' => ''
+              },
               'parent' => {},
               'type' => 'menu_entry'
             },
@@ -375,7 +383,11 @@ $result_trees{'node_footnote_separated'} = {
                   'normalized' => '_00e0'
                 }
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => 'node_footnote.texi',
+                'line_nr' => 11,
+                'macro' => ''
+              },
               'parent' => {},
               'type' => 'menu_entry'
             },
@@ -433,7 +445,9 @@ $result_trees{'node_footnote_separated'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'Top'
           }
         ],
@@ -570,7 +584,11 @@ $result_trees{'node_footnote_separated'} = {
               ],
               'cmdname' => 'footnote',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => 'node_footnote.texi',
+                'line_nr' => 17,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -595,14 +613,20 @@ $result_trees{'node_footnote_separated'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => '_00e1'
           }
         ],
         'normalized' => '_00e1',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => 'node_footnote.texi',
+        'line_nr' => 14,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -728,7 +752,11 @@ $result_trees{'node_footnote_separated'} = {
               ],
               'cmdname' => 'footnote',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => 'node_footnote.texi',
+                'line_nr' => 22,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -753,14 +781,20 @@ $result_trees{'node_footnote_separated'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => '_00e2'
           }
         ],
         'normalized' => '_00e2',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => 'node_footnote.texi',
+        'line_nr' => 19,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -788,7 +822,9 @@ $result_trees{'node_footnote_separated'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => 'chapter'
           }
         ],
@@ -906,7 +942,11 @@ $result_trees{'node_footnote_separated'} = {
                   'normalized' => '_00e0'
                 }
               },
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => 'node_footnote.texi',
+                'line_nr' => 28,
+                'macro' => ''
+              },
               'parent' => {},
               'type' => 'menu_entry'
             },
@@ -1093,7 +1133,11 @@ $result_trees{'node_footnote_separated'} = {
               ],
               'cmdname' => 'footnote',
               'contents' => [],
-              'line_nr' => {},
+              'line_nr' => {
+                'file_name' => 'node_footnote.texi',
+                'line_nr' => 34,
+                'macro' => ''
+              },
               'parent' => {}
             },
             {
@@ -1118,14 +1162,20 @@ $result_trees{'node_footnote_separated'} = {
         ],
         'nodes_manuals' => [
           {
-            'node_content' => [],
+            'node_content' => [
+              {}
+            ],
             'normalized' => '_00e0'
           }
         ],
         'normalized' => '_00e0',
         'spaces_before_argument' => ' '
       },
-      'line_nr' => {},
+      'line_nr' => {
+        'file_name' => 'node_footnote.texi',
+        'line_nr' => 31,
+        'macro' => ''
+      },
       'parent' => {}
     },
     {
@@ -1168,7 +1218,6 @@ $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0]{'args'}[0];
@@ -1181,7 +1230,6 @@ $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_description'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[3];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'args'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[3];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[1]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[3]{'args'}[1];
@@ -1204,7 +1252,6 @@ $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[3]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'extra'}{'menu_entry_description'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[3];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[1]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'args'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[5]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'contents'}[5];
@@ -1213,7 +1260,7 @@ $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'extra'}{
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'extra'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'node_footnote_separated'}{'contents'}[1]{'extra'}{'node_content'};
+$result_trees{'node_footnote_separated'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'};
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'args'}[0]{'contents'}[0];
@@ -1232,14 +1279,12 @@ $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4];
-$result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'contents'}[2]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[2];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'extra'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[2]{'args'}[0]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'extra'}{'node_content'};
-$result_trees{'node_footnote_separated'}{'contents'}[2]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[2]{'args'}[0]{'contents'}[0]{'line_nr'};
+$result_trees{'node_footnote_separated'}{'contents'}[2]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[2]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[2]{'parent'} = $result_trees{'node_footnote_separated'};
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'args'}[0]{'contents'}[0];
@@ -1258,19 +1303,17 @@ $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4];
-$result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'contents'}[2]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[3];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'extra'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[3]{'args'}[0]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'extra'}{'node_content'};
-$result_trees{'node_footnote_separated'}{'contents'}[3]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[3]{'args'}[0]{'contents'}[0]{'line_nr'};
+$result_trees{'node_footnote_separated'}{'contents'}[3]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[3]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[3]{'parent'} = $result_trees{'node_footnote_separated'};
 $result_trees{'node_footnote_separated'}{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[4]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[4];
 $result_trees{'node_footnote_separated'}{'contents'}[4]{'extra'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[4]{'args'}[0]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'node_footnote_separated'}{'contents'}[4]{'extra'}{'node_content'};
+$result_trees{'node_footnote_separated'}{'contents'}[4]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[4]{'parent'} = $result_trees{'node_footnote_separated'};
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[5]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[5];
@@ -1288,7 +1331,6 @@ $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'args'}[3]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_description'} = $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'args'}[3];
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'extra'}{'menu_entry_node'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'args'}[1]{'contents'}[0]{'line_nr'};
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[2]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[5]{'contents'}[1]{'contents'}[2];
@@ -1314,14 +1356,12 @@ $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'args'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4];
-$result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'args'}[0]{'contents'}[0]{'contents'}[1]{'line_nr'};
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1];
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[1]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[6];
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'contents'}[2]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[6];
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'extra'}{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[6]{'args'}[0]{'contents'}[0];
-$result_trees{'node_footnote_separated'}{'contents'}[6]{'extra'}{'nodes_manuals'}[0]{'node_content'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'extra'}{'node_content'};
-$result_trees{'node_footnote_separated'}{'contents'}[6]{'line_nr'} = $result_trees{'node_footnote_separated'}{'contents'}[6]{'args'}[0]{'contents'}[0]{'line_nr'};
+$result_trees{'node_footnote_separated'}{'contents'}[6]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0] = $result_trees{'node_footnote_separated'}{'contents'}[6]{'args'}[0]{'contents'}[0];
 $result_trees{'node_footnote_separated'}{'contents'}[6]{'parent'} = $result_trees{'node_footnote_separated'};
 $result_trees{'node_footnote_separated'}{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'node_footnote_separated'}{'contents'}[7];
 $result_trees{'node_footnote_separated'}{'contents'}[7]{'parent'} = $result_trees{'node_footnote_separated'};
@@ -1495,18 +1535,7 @@ $result_nodes{'node_footnote_separated'} = {
       }
     }
   ],
-  'node_next' => {},
-  'node_up' => {
-    'extra' => {
-      'manual_content' => [
-        {
-          'text' => 'dir'
-        }
-      ],
-      'top_node_up' => {}
-    },
-    'type' => 'top_node_up'
-  }
+  'node_next' => {}
 };
 $result_nodes{'node_footnote_separated'}{'menu_child'}{'node_next'}{'node_next'}{'menu_child'}{'node_prev'} = $result_nodes{'node_footnote_separated'}{'menu_child'}{'node_next'}{'node_next'};
 $result_nodes{'node_footnote_separated'}{'menu_child'}{'node_next'}{'node_next'}{'menu_child'}{'node_up'} = $result_nodes{'node_footnote_separated'}{'menu_child'}{'node_next'}{'node_next'};
@@ -1518,7 +1547,6 @@ $result_nodes{'node_footnote_separated'}{'menu_child'}{'node_next'}{'node_up'} =
 $result_nodes{'node_footnote_separated'}{'menu_child'}{'node_prev'} = $result_nodes{'node_footnote_separated'};
 $result_nodes{'node_footnote_separated'}{'menu_child'}{'node_up'} = $result_nodes{'node_footnote_separated'};
 $result_nodes{'node_footnote_separated'}{'node_next'} = $result_nodes{'node_footnote_separated'}{'menu_child'};
-$result_nodes{'node_footnote_separated'}{'node_up'}{'extra'}{'top_node_up'} = $result_nodes{'node_footnote_separated'};
 
 $result_menus{'node_footnote_separated'} = {
   'cmdname' => 'node',
@@ -1585,35 +1613,10 @@ $result_menus{'node_footnote_separated'}{'menu_child'}{'menu_next'}{'menu_prev'}
 $result_menus{'node_footnote_separated'}{'menu_child'}{'menu_next'}{'menu_up'} = $result_menus{'node_footnote_separated'};
 $result_menus{'node_footnote_separated'}{'menu_child'}{'menu_up'} = $result_menus{'node_footnote_separated'};
 
-$result_errors{'node_footnote_separated'} = [
-  {
-    'error_line' => 'node_footnote.texi:24: warning: node `@`a\' is next for `chapter\' in menu but not in sectioning
-',
-    'file_name' => 'node_footnote.texi',
-    'line_nr' => 24,
-    'macro' => '',
-    'text' => 'node `@`a\' is next for `chapter\' in menu but not in sectioning',
-    'type' => 'warning'
-  },
-  {
-    'error_line' => 'node_footnote.texi:24: warning: node `@^a\' is prev for `chapter\' in menu but not in sectioning
-',
-    'file_name' => 'node_footnote.texi',
-    'line_nr' => 24,
-    'macro' => '',
-    'text' => 'node `@^a\' is prev for `chapter\' in menu but not in sectioning',
-    'type' => 'warning'
-  },
-  {
-    'error_line' => 'node_footnote.texi:24: warning: node `Top\' is up for `chapter\' in menu but not in sectioning
-',
-    'file_name' => 'node_footnote.texi',
-    'line_nr' => 24,
-    'macro' => '',
-    'text' => 'node `Top\' is up for `chapter\' in menu but not in sectioning',
-    'type' => 'warning'
-  }
-];
+$result_errors{'node_footnote_separated'} = [];
+
+
+$result_floats{'node_footnote_separated'} = {};
 
 
 $result_converted_errors{'file_html'}->{'node_footnote_separated'} = [
